==> haskell-tasty-1.2.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 1.2.3
id: tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
key: tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
category: Testing
abi: 66c7f5fd3fca920cf2c245e213214a44
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Types Test.Tasty.Providers Test.Tasty.Runners
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
                Test.Tasty.Runners.Utils Test.Tasty.CmdLine
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-1.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-1.2.3
hs-libraries: HStasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    clock-0.8-H1S1zDefxirImaRbI6ITNv containers-0.6.0.1 mtl-2.2.2
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5 stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    unbounded-delays-0.1.1.0-7ulHERuvlgAKyhaTH4vNZc unix-2.7.2.2
    wcwidth-0.0.2-HlBWSHd0u0t4BLF0paIjbe
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-1.2.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 1.2.3
id: tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
key: tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
category: Testing
abi: 822d85e98efb40998d5a439085ef2270
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Types Test.Tasty.Providers Test.Tasty.Runners
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
                Test.Tasty.Runners.Utils Test.Tasty.CmdLine
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-1.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-1.2.3
hs-libraries: HStasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    clock-0.8-H1S1zDefxirImaRbI6ITNv containers-0.6.0.1 mtl-2.2.2
    optparse-applicative-0.15.1.0-3zohG31eF19CsmDcrOZBbb stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    unbounded-delays-0.1.1.0-7ulHERuvlgAKyhaTH4vNZc unix-2.7.2.2
    wcwidth-0.0.2-HlBWSHd0u0t4BLF0paIjbe
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
